@@ -57,7 +57,7 @@ class MixinMeta(type):
 
 
 @six.add_metaclass(MixinMeta)
-class PythonConstant(object):
+class PythonConstant:
   """A mix-in for storing actual Python constants, not just their types.
 
   This is used for things that are stored in cfg.Variable, but where we
@@ -90,7 +90,7 @@ class PythonConstant(object):
 
 
 @six.add_metaclass(MixinMeta)
-class HasSlots(object):
+class HasSlots:
   """Mix-in for overriding slots with custom methods.
 
   This makes it easier to emulate built-in classes like dict which need special
@@ -135,7 +135,7 @@ class HasSlots(object):
 
 
 @six.add_metaclass(MixinMeta)
-class Class(object):
+class Class:
   """Mix-in to mark all class-like values."""
 
   overloads = ("get_special_attribute", "get_own_new", "call", "compute_mro")
@@ -440,3 +440,32 @@ class Class(object):
 
     # calc MRO and replace them with original base classes
     return tuple(base2cls[base] for base in mro.MROMerge(newbases))
+
+
+@six.add_metaclass(MixinMeta)
+class NestedAnnotation:
+  """An annotation containing inner types, such as a Union.
+
+  For example, in `Union[int, str]`, `int` and `str` are the annotation's inner
+  types. Classes that inherit from this mixin should implement:
+
+  get_inner_types(): Returns a sequence of (key, typ) of the inner types. A
+  Union's inner types can be keyed on their position: `[(0, int), (1, str)]`.
+
+  update_inner_type(key, typ): Updates the inner type with the given key.
+
+  replace(inner_types): Returns a new annotation that is a copy of the current
+    one but with the given inner types, again as a (key, typ) sequence.
+  """
+
+  def init_mixin(self):
+    self.processed = False
+
+  def get_inner_types(self):
+    raise NotImplementedError()
+
+  def update_inner_type(self, key, typ):
+    raise NotImplementedError()
+
+  def replace(self, inner_types):
+    raise NotImplementedError()
